@@ -82,7 +82,7 @@ static void  gdl_dock_forall          (GtkContainer *container,
                                        gboolean      include_internals,
                                        GtkCallback   callback,
                                        gpointer      callback_data);
-static GtkType  gdl_dock_child_type   (GtkContainer *container);
+static GType  gdl_dock_child_type   (GtkContainer *container);
 
 static void     gdl_dock_detach       (GdlDockObject    *object,
                                        gboolean          recursive);
@@ -750,7 +750,7 @@ gdl_dock_forall (GtkContainer *container,
         (*callback) (GTK_WIDGET (dock->root), callback_data);
 }
 
-static GtkType
+static GType
 gdl_dock_child_type (GtkContainer *container)
 {
     return GDL_TYPE_DOCK_ITEM;
@@ -1128,6 +1128,8 @@ gdl_dock_select_larger_item (GdlDockItem *dock_item_1,
         return ((size_1.width * size_1.height)
                     >= (size_2.width * size_2.height)?
                     dock_item_1 : dock_item_2);
+    } else if (placement == GDL_DOCK_NONE) {
+	return dock_item_1;
     } else {
         g_warning ("Should not reach here: %s:%d", __FUNCTION__, __LINE__);
     }
